#
# spec file for package upmpdcli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           upmpdcli
Version:        1.9.0
Release:        1.2
Summary:        UPnP AV and OpenHome Media Renderer front-end to MPD, the Music Player Daemon
License:        GPL-2.0-or-later
URL:            https://www.lesbonscomptes.com/updmpdcli
Source0:        https://www.lesbonscomptes.com/upmpdcli/downloads/upmpdcli-%{version}.tar.gz
Source1:        https://www.lesbonscomptes.com/upmpdcli/downloads/upmpdcli-%{version}.tar.gz.asc
Source2:        https://www.lesbonscomptes.com/pages/jf-at-dockes.org.pub#/%{name}.keyring
Patch0:         harden_upmpdcli.service.patch
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  group(audio)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libmpdclient)
BuildRequires:  pkgconfig(libnpupnp)
BuildRequires:  pkgconfig(libupnpp) >= 0.26.0
Requires:       python3-requests
Requires(pre):  group(audio)
Requires(pre):  shadow
Suggests:       %{name}-bbc
Suggests:       %{name}-hra
Suggests:       %{name}-mother-earth-radio
Suggests:       %{name}-radio-browser
Suggests:       %{name}-radio-paradise
Suggests:       %{name}-radios
Suggests:       %{name}-subsonic
Suggests:       %{name}-tidal
%{?systemd_ordering}

%description
Upmpdcli turns MPD, the Music Player Daemon into an UPnP AV and/or OpenHome Media Renderer
remotely controllable by most UPnP/DLNA/OpenHome Control Point apps (notably on mobile devices).
It can also operate as an UPnP/DLNA Media Server to give access to various online audio content via plugins available as optional packages.

%prep
%autosetup -p1

%build
export QMAKE=qmake-qt5
%meson -Dscctl=true -Dconfgui=true
%meson_build

%install
%meson_install
rm %{buildroot}%{_sysconfdir}/upmpdcli.conf-dist

install -D -m 644 systemd/upmpdcli.service %{buildroot}%{_unitdir}/upmpdcli.service
mkdir -p %{buildroot}/%{_sbindir}
ln -s service %{buildroot}/%{_sbindir}/rcupmpdcli

%files
%license COPYING
%doc AUTHORS
%{_bindir}/%{name}
%{_bindir}/scctl
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/AVTransport.xml
%{_datadir}/%{name}/ConnectionManager.xml
%{_datadir}/%{name}/ContentDirectory.xml
%{_datadir}/%{name}/MS-description.xml
%{_datadir}/%{name}/OHCredentials.xml
%{_datadir}/%{name}/OHInfo.xml
%{_datadir}/%{name}/OHPlaylist.xml
%{_datadir}/%{name}/OHProduct.xml
%{_datadir}/%{name}/OHRadio.xml
%{_datadir}/%{name}/OHReceiver.xml
%{_datadir}/%{name}/OHTime.xml
%{_datadir}/%{name}/OHVolume.xml
%{_datadir}/%{name}/RenderingControl.xml
%{_datadir}/%{name}/cdplugins/pycommon
%{_datadir}/%{name}/description.xml
%{_datadir}/%{name}/icon.png
%{_datadir}/%{name}/presentation.html
%{_datadir}/%{name}/protocolinfo.txt
%{_datadir}/%{name}/radio_scripts
%{_datadir}/%{name}/rdpl2stream
%{_datadir}/%{name}/src_scripts
%{_datadir}/%{name}/upmpdcli.conf-dist
%{_datadir}/%{name}/upmpdcli.conf-xml
%{_datadir}/%{name}/web
%dir %{_datadir}/%{name}/cdplugins
# don't package qobuz as plugin because it is also required for providing OpenHome Credentials Qobuz functionality
%{_datadir}/%{name}/cdplugins/qobuz
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man5/%{name}.conf.5%{?ext_man}
%{_unitdir}/upmpdcli.service
%{_sbindir}/rcupmpdcli
%config(noreplace) %{_sysconfdir}/upmpdcli.conf

%pre
getent passwd upmpdcli >/dev/null || useradd -r -g audio -d /nonexistent -s /sbin/nologin -c "user for upmpdcli" upmpdcli
%service_add_pre upmpdcli.service

%post
%service_add_post upmpdcli.service

%preun
%service_del_preun upmpdcli.service

%postun
%service_del_postun upmpdcli.service

####

%package config
Summary:        GUI configuration editor for upmpdcli
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Widgets)

%description config
QT-based GUI for editing upmpdcli configuration files.

%files config
%{_bindir}/upmpdcli-config

########## MEDIA SERVER PLUGINS

%package bbc
Summary:        BBC radio media server plugin for upmpdcli
Requires:       python3-beautifulsoup4
Requires:       python3-dateutil
Requires:       python3-feedparser
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description bbc
Media Server plugin providing access to BBC radio streams.

%files bbc
%{_datadir}/%{name}/cdplugins/bbc

%package hra
Summary:        HIGHRESAUDIO media server plugin for upmpdcli
Requires:       python3-requests
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description hra
Media Server plugin providing access to the HIGHRESAUDIO
music streaming service (https://www.highresaudio.com/en).

%files hra
%{_datadir}/%{name}/cdplugins/hra

####

%package mother-earth-radio
Summary:        Mother Earth Radio media server plugin for upmpdcli
Requires:       python3-requests
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description mother-earth-radio
Media Server plugin providing access to Mother Earth Radio streams.

%files mother-earth-radio
%{_datadir}/%{name}/cdplugins/mother-earth-radio

####

%package radio-browser
Summary:        https://radio-browser.info media server plugin for upmpdcli
Requires:       python3-requests
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description radio-browser
Media Server plugin providing access to the radio-browser site catalog
(https://radio-browser.info)
You will need to install the pyradios Python3 module with pip3.

%files radio-browser
%{_datadir}/%{name}/cdplugins/radio-browser

####

%package radio-paradise
Summary:        Radio Paradise media server plugin for upmpdcli
Requires:       python3-requests
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description radio-paradise
Media Server plugin providing access to the Radio Paradise streams.

%files radio-paradise
%{_datadir}/%{name}/cdplugins/radio-paradise

####

%package subsonic
Summary:        Subsonic media server plugin for upmpdcli
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description subsonic
Media Server plugin providing access to a Subsonic or Navidrome server.
It needs the installation of the subsonic-connector (version 0.3.1)
and py-sonic (version 1.0.0) Python modules (not packaged, use Pypi).

%files subsonic
%{_datadir}/%{name}/cdplugins/subsonic

####

%package tidal
Summary:        TIDAL media server plugin for upmpdcli
Requires:       python3-requests
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description tidal
Media Server plugin providing access to the TIDAL music streaming service.
You will need to install the tidalapi Python3 module with pip3.

%files tidal
%{_datadir}/%{name}/cdplugins/tidal

####

%package radios
Summary:        OpenHome Radio Service media server plugin for upmpdcli
Requires:       python3-requests
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description radios
Media Server plugin providing access to radios managed by the OpenHome Radio Service.

%files radios
%{_datadir}/%{name}/cdplugins/upradios

####

%package uprcl
Summary:        Recoll media server plugin for upmpdcli
Requires:       python3-mutagen
Requires:       python3-requests
Requires:       python3-waitress
Requires:       upmpdcli = %{version}
BuildArch:      noarch

%description uprcl
Media Server plugin providing access to Recoll indexed media.
For use with recoll package found in KDE:Extra

%files uprcl
%{_datadir}/%{name}/cdplugins/uprcl

%changelog
* Wed Dec  4 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to 1.9.0
  * Fix most glaring issues in the Qobuz plugin
  * Qobuz: updated the plugin to be closer to the choices on the Web
    site (reason for the middle version bump)
  * Qobuz: fixed the search to better return what actually requested
  * Tidal: updated plugin
  * Misc fixes: restore custom icon support, clear "phantom" track from mpd
    to avoid its reappearance on startup
* Thu Aug 22 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to 1.8.16:
  * Fix opening log file when started as root
  * Updates to the Tidal and Subsonic plugins
  * Uprcl compatibility with Recoll 1.40
* Sun May 12 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to 1.8.10:
  * Moved build system from autotools to meson
- Update to 1.8.9:
  * Add man page for the config file
  * Small internal cleanups. Always set id and parentId when generating didl
- Update to 1.8.8:
  * Tidal: avoid SQL error with older sqlite versions
  * Misc subsonic and Tidal improvements
- Update to 1.8.7:
  * Misc small plugins fixes
* Sat Dec 23 2023 Michael Pujos <pujos.michael@gmail.com>
- each Content Directory plugin is now packaged in its own noarch package
  instead of being bundled in the main package
- added upmpdcli-config package, a Qt5 config editor.
  Global upmpdcli config can be edited with command:
  xdg-su upmpdcli-config /etc/upmpdcli.conf
- fixed permission on /etc/upmpdcli.conf preventing plugins to read
  their configuration
- Update to 1.8.6:
  * Fix issues in the HTTP streaming proxy. They were preventing its use with Kodi.
- Update to 1.8.5:
  * Remove deezer support, it was not working any more.
- Update to 1.8.4:
  * Rebuilt for new npupnp/upnpp libs version numbering.
  * Rebuilt for rpi 1 (armv6) compatibility
  * Misc. improvements to the Tidal, Subsonic,and Radio Paradise Media
    Server plugins.
  * New Mother Earth Radio Media Server plugin.
- Update to 1.8.3:
  * Completely new Tidal plugin by Giovanni Fulco. Tidal access is
    working again !
  * Media Server: change the internal URL format to avoid characters
    needing quoting in XML: work around misc. device bugs.
  * Qobuz: add option to obtain actual item resource info when listing
    a container.
- Update to 1.8.1:
  * Add configuration variable to enable the internal WEB server local
    file serving function, mostly for use by Media Server plugins for
    serving icons. Off by default.
  * Subsonic/Navidrome plugin: misc. updates and improvements.
  * Uprcl: fix using the 'albumartist' tag in priority when it is set.
- Update to 1.7.9:
  * Media Server: new Subsonic connector plugin by Giovanni Fulco:
    allows streaming music from a Subsonic/Navidrome server to an UPnP renderer.
* Thu Mar 23 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to 1.7.7:
  * Media Server: fix issues in upnp-to-recoll search translation,
    and improve search behaviour with some control points
    (BubbleUPnP and Linn Kazoo).
  * Fix potential issues with parallel requests.
  * Uprcl: index artist documents so that they can be searched for
  * When a search request is relative to objid "0", use the plugin
    root instead of last browsed container.
  * Avoid phantom entries by adjusting the result count for entries
    filtered out by class.
- Update to 1.7.2:
  * Fix URL comparison issue which could cause false diags in checkContentFormat()
  * Change the default value for checkcontentformat from true to false.
  * Qobuz: always use https.
  * New radio-browser Media Server plugin for https://www.radio-browser.info/
  * Ensure that we exit when getting a terminating signal while waiting
    for mpd during init
- Update to 1.7.1:
  * Uprcl Media Server: report composers as <upnp:artist role="Composer">
  * Uprcl: fix possible infinite loop while parsing search string.
- Update to 1.7.0:
  * Media Server: implement rootalias parameter to point to arbitrary
    container inside the tree. This is to avoid useless navigation from
    the actual root for people who, e.g., only use the uprcl '[folders]' tree.
  * Uprcl: support multiple values for tags (e.g. multiple genres).
  * Uprcl: fix miscellaneous small issues.
  * Removed Spotify support as libspotify does not work any more.
* Sat Dec  3 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.6.2:
  * Media Server: uprcl, qobuz, upradios: properly implement
    UPnP Browse(Metadata), for the sole use of Kodi, probably.
  * Uprcl container sort: sort by file names if there are no tags
    (e.g. wav files).
  * Uprcl: add uprclnotag view configuration variable to disable the
    "Tag View" entries in the folders tree.
  * Make configuration parameter names case-insensitive
  * Small bugs fixes
- update to 1.6.1:
  * uprcl: process custom tags (not predefined anywhere) as regular ones.
  * main: change order of media server and renderer initialisations so
    that the media server does not have to wait for mpd.
- update to 1.6.0:
  * Allow all configuration variables to also be set through
    environment variables named UPMPD_xxx where xxx is the upper-cased
    version of the variable name. This should facilitate running
    upmpdcli in a container.
  * Change the names of the low level UPnP library log variables from
    UPMPDCLI_xxx to UPMPD_xxx and manage them in the same way as the rest
    (with config entries too).
  * Allow substituting the host name (%%h,%%H) and version info (%%v) in
    the configured friendlyname. The default friendlyname is now UpMpd-%%h
  * Uprcl: use same host as upmpdcli by default. Add uprclport configuration
    variable to only set the port
- update to 1.5.20:
  * Uprcl: preserve stored playlist order
  * Uprcl: choose folder image file rather than track-embedded art for folder or album
  * Uprcl: misc fixes.
* Sat Aug 13 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.19:
  * Fix uprcl web control interface (asking for update did not work)
  * Fix upradios stations list order
- update to 1.5.18:
  * Create an upmpdcli group during installation and change the group
    to upmpdcli when started as root (in addition to the setuid())
  * uprcl: try to show more information when the initialisation fails
* Wed Jun  1 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.17:
  * Fix Qobuz plugin consecutively to small change in Qobuz interface
- update to 1.5.16:
  * Fix radios using Apple Live Streaming, which were broken in 1.5.14
- update to 1.5.15:
  * Fix possible deadlocks when switching to Songcast mode
- update to 1.5.14:
  * Added mediaserver module for listing and listening to  BBC radio stations
* Sun Mar 20 2022 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Tue Dec 14 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.13:
  * Enable L16 by default as it is handled correctly by current mpd versions
  * Add the mpd version to the description version string
  * Change Qobuz default format to 6 (44.1/16 FLAC)
  * Misc small bug fixes
- update to 1.5.12:
  * Add small Media Server plugin (upradios) for exporting the radio list
  * uprcl: export the radio list as a playlist
  * uprcl: small improvements
  * Deezer, Qobuz: set pictures for artists and playlists
* Fri Nov 26 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_upmpdcli.service.patch
* Thu Apr 15 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.11:
  * Fix rare possible issue with Kazoo volume control
  * Passthrough for CDDA urls. An URL of the form:
    http://upmpdprotoescape/cdda/dev/sr0/1
    will be translated to: cdda:///dev/sr0/1
    This hack allows tunneling CDDA URLs, which mpd understands but
    some control points don’t like, for example, to construct a
    playlist which will play the tracks from a CD device
  * Reconnect the event loop when mpd restarts. Before the fix,
    events stopped being generated after mpd restarted
  * Radio metadata issues fixed
  * Media Server: Deezer streaming service plugin
  * Fix events not working when mpd had password set
* Tue Jan 19 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.8:
  * Fix a number of memory leak and locking issues detected by valgrind/helgrind.
  * Improve performance of big playlist insert by rate-limiting events.
  * Fix possible crash when started while mpd is not running.
* Thu Dec 31 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.7:
  * Fix timeout issue while in long pause
    (>60S, play transition started from other client was not detected)
  * Fix ohinfo issue resulting in no cover art display in Kazoo "currently playing" screen.
  * Fix a number of issues in radio metadata.
  * The minimum effective volume adjustment was 5. Reset it to 1.
  * Cache update issues in OH playlist resulted in incomplete metadata.
* Wed Dec  9 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.5:
  * Fix issue with removing tracks from the playlist (sometimes slow or freezed).
  * Fix bad locking causing multiple execs of radio scripts.
  * Setting lumincompat = 1 is not useful any more and crashes some Kazoo versions.
    So you should keep the default value which is off.
  * Improve metadata processing when playing radios with BubbleDS.
* Wed Nov 25 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.2:
  * Modify a few things which should not have mattered but which prevented Lumin to work with upmpdcli
  * Qobuz plugin working again (for now), by identifying itself as the web client (thanks to qobuz-dl on github)
  * Fixed crash
  * Will now generate events for bitrate changes when playing
- update to 1.5.1:
  * Fix small issue resulting in missing metadata in ohinfo
* Thu Nov 19 2020 Michael Pujos <pujos.michael@gmail.com>
- removed unneeded systemd.obscpio
- spec: removed unneeded %%global __python python3
- spec: removed unneeded autoconf, automake build deps
* Sun Nov 15 2020 Michael Pujos <pujos.michael@gmail.com>
- update to upstream version 1.5.0
* Sat May 16 2020 Michael Pujos <pujos.michael@gmail.com>
- added explicit dependency on libupnp to force packqhe recompilaiton
  when libupnp version changes (eg libupnp15 => libupnp16)
* Fri Jan 24 2020 Michael Pujos <pujos.michael@gmail.com>
- Initial version of upmpdcli 1.4.5
